RoomIndex

Struct RoomIndex 

pub struct RoomIndex { /* private fields */ }
A struct that holds all data pertaining to a particular room’s message index.

Implementations

Source

impl RoomIndex

pub fn search( &self, query: &str, max_number_of_results: usize, pagination_offset: Option<usize>, ) -> Result<Vec<(f32, OwnedEventId)>, IndexError>

Search the RoomIndex for some query. Returns a list of results with a maximum given length. If pagination_offset is set then the results will start there, i.e.

if max_number_of_results = 3 and pagination_offset = 10 (and there are a surplus of results) then this will return results 11, 12, 13

pub fn execute( &mut self, operation: RoomIndexOperation, ) -> Result<(), IndexError>

Execute RoomIndexOperation

If an error occurs, retry 5 times if possible.

This which will add/remove/edit an event in the index based on the operation.

Prefer RoomIndex::bulk_execute for multiple operations.

pub fn bulk_execute( &mut self, operations: Vec<RoomIndexOperation>, ) -> Result<(), IndexError>

Bulk execute RoomIndexOperations

If an error occurs in the batch it retries 5 times if possible.

This which will add/remove/edit an events in the index based on the operations.

Waits for background merge threads to prevent racing with subsequent calls.