pub struct SearchResult {
pub total_count: usize,
pub events: Vec<(f32, OwnedEventId)>,
}Expand description
The result type for a search operation.
Fields
total_count: usizeThe total count of search results that were found.
Might be bigger than the length of SearchResult::events as the
search is paginated.
events: Vec<(f32, OwnedEventId)>A list of search results.
Each entry contains the search score and the ID of the event that
matched the search query. The list may be incomplete because the search
results are paginated; use SearchResult::total_count to determine
the total number of matching results.